# MetaboConverter
# Excel Sheet Viewer

A Python package that allows users to view and analyze Excel sheets through a GUI.

## Installation

In your system terminal (make sure you have python installed), type: pip install MetaboConverter

## Usage

Once Installation is finished, type:
python
in your termial and then copy the following

```python
import MetaboConverter as pk
pk.runApp()
